@@ -1,7 +1,7 @@
 from typing import Dict
 
 
-def print_map(score_map: Dict[str, float], asc=False, line_format="{}: {}\n") -> None:
+def print_map(score_map: Dict[str, float], asc: bool = False, line_format: str = "{}: {}\n") -> None:
     """ Print a map from names to numbers ordered by the number.
 
     Args:
@@ -12,6 +12,6 @@ def print_map(score_map: Dict[str, float], asc=False, line_format="{}: {}\n") ->
     items = list(score_map.items())
     order_coef = 1 if asc else -1
     sorted_items = sorted(items, key=lambda x: order_coef * x[1])
-    for k, v in sorted_items:
-        line = line_format.format(k, v)
+    for key, value in sorted_items:
+        line = line_format.format(key, value)
         print(line, end="")
